///File : ControlDialog.cpp
//------------------------------------------------------------------------------
/*
    This file is part of LCDnurse.

    LCDnurse is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LCDnurse is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LCDnurse.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "ControlDialog.hpp"

#include "MainPanel.hpp"
//------------------------------------------------------------------------------
/*BEGIN_EVENT_TABLE(ControlDialog, wxDialog)
    EVT_KEY_DOWN(ControlDialog::KeyDown)
END_EVENT_TABLE()*/
//------------------------------------------------------------------------------
ControlDialog::ControlDialog( wxWindow* parent, wxWindowID id, wxString name, DataManager *Data, const wxPoint& pos, const wxSize& size, long style ) : wxDialog( parent, id, name, pos, size, style )
{
    // DataManager
    m_Data = Data;

    // Icon
    SetIcon(static_cast<wxTopLevelWindow*>(GetParent()->GetParent())->GetIcon());

    // Controls
	wxBoxSizer *MainSizer = new wxBoxSizer( wxVERTICAL );

    // 1 : Infos + dell All
    MainSizer->Add(new wxStaticText(this, wxID_ANY, _("Number of dead pixels :")), 0, wxLEFT | wxEXPAND, 10);
    m_RectNbTxt = new wxTextCtrl(this, wxID_ANY, _T(""), wxDefaultPosition, wxDefaultSize, wxTE_READONLY | wxTE_CENTRE );
    m_RectNbTxt->Disable();
    MainSizer->Add(m_RectNbTxt, 0, wxALL | wxEXPAND, 5);

    m_DelAllBt = new wxButton(this, wxID_DELETE, _("Delete &All"));
    MainSizer->Add(m_DelAllBt, 0, wxALL | wxEXPAND, 5);

    MainSizer->AddSpacer(20);

    // 2 : Frequence
    MainSizer->Add(new wxStaticText(this, wxID_ANY, _("Period (ms) :")), 0, wxLEFT | wxEXPAND, 10);
    m_PeriodSpinCtrl = new wxSpinCtrl(this, Id_FrequenceSpin, _T(""), wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 3, 100000);
    MainSizer->Add(m_PeriodSpinCtrl, 0, wxALL | wxEXPAND, 5);
    MainSizer->AddSpacer(20);

    // 2.5 : Color
    MainSizer->Add(new wxStaticText(this, wxID_ANY, _("Background color :")), 0, wxLEFT | wxEXPAND, 10);
    wxString colorsTbl[COLORS_LIST_SIZE] = {COLORS_NAME_LIST};
    m_ColorChoice = new wxChoice(this, Id_ColorChoice, wxDefaultPosition, wxDefaultSize, COLORS_LIST_SIZE, colorsTbl);
    MainSizer->Add(m_ColorChoice, 0, wxALL | wxEXPAND, 5);

    // 3 : Bts
    m_HelpBt = new wxButton(this, wxID_HELP);
    MainSizer->Add(m_HelpBt, 0, wxALL | wxEXPAND, 5);

    m_AboutBt = new wxButton(this, wxID_ABOUT);
    MainSizer->Add(m_AboutBt, 0, wxALL | wxEXPAND, 5);

    m_HideBt = new wxButton(this, wxID_CLOSE );
    MainSizer->Add(m_HideBt, 0, wxALL | wxEXPAND, 5);

    m_RepairBt = new wxButton(this, wxID_ANY, _("Repair"));
    MainSizer->Add(m_RepairBt, 0, wxALL | wxEXPAND, 5);

    m_QuitBt = new wxButton(this, wxID_EXIT);
    MainSizer->Add(m_QuitBt, 0, wxALL | wxEXPAND, 5);
    // Sizer
	SetSizer(MainSizer);
	MainSizer->Fit(this);

	// Events
        // Bts
	Connect( wxID_DELETE, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(ControlDialog::OnDeleteAll));
    Connect( wxID_HELP, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(ControlDialog::OnHelp));
    Connect( wxID_ABOUT, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(ControlDialog::OnAbout));
    Connect( wxID_CLOSE, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(ControlDialog::OnPanelHide));
    Connect( wxID_EXIT, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(ControlDialog::OnQuit));
    m_RepairBt->Connect( wxID_ANY, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(ControlDialog::OnRepair), NULL, this);

        // Choice
    Connect( Id_ColorChoice, wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler(ControlDialog::OnColorChoice));

        // Spin
    Connect( Id_FrequenceSpin, wxEVT_COMMAND_TEXT_UPDATED, wxTextEventHandler(ControlDialog::OnPeriodSpin));

    //Connect( wxID_ANY, wxEVT_KEY_DOWN, wxKeyEventHandler(ControlDialog::KeyDown));

    // Refresh
    MyRefresh();
}
//------------------------------------------------------------------------------
void ControlDialog::OnRepair(wxCommandEvent &event)
{
    MainPanel *mainPanel = static_cast<MainPanel*>(GetParent());
    mainPanel->StartRepair();
}
//------------------------------------------------------------------------------
void ControlDialog::MyRefresh()
{
    m_PeriodSpinCtrl->SetValue(m_Data->GetPeriod());

    wxString str;
    str << m_Data->GetRectCount();
    m_RectNbTxt->SetValue(str);

    m_ColorChoice->SetSelection(m_Data->GetBackgroundColor());
}
//------------------------------------------------------------------------------

void ControlDialog::OnQuit(wxCommandEvent& event)
{
    GetParent()->GetParent()->Close();
}
//------------------------------------------------------------------------------
void ControlDialog::OnPanelHide(wxCommandEvent& event)
{
    Hide();
}
//------------------------------------------------------------------------------
void ControlDialog::OnAbout(wxCommandEvent& event)
{
    DialogAbout MyDialogAbout(this, wxID_ANY);
    MyDialogAbout.ShowModal();
}
//------------------------------------------------------------------------------
void ControlDialog::OnHelp(wxCommandEvent& event)
{
    wxMessageBox(_("Keys :\n"
    " - Escpae : Show the menu.\n"
    " - Space / Mouse Weel : Change the background color.\n"
    " - Del : Delete the pointed rectangle.\n"
    " - Click : Begin a new rectangle or enable the current one.\n"
    "\n"
    "You should select LDC Nurse Saver as your screen saver."
    ""), _("Help"), wxOK | wxICON_QUESTION, this);
}
//------------------------------------------------------------------------------
void ControlDialog::OnDeleteAll(wxCommandEvent& event)
{
    if(wxMessageBox(_("Are you sure ?"), _("Delete All"), wxYES_NO | wxNO_DEFAULT | wxICON_EXCLAMATION, this) == wxYES)
    {
        m_Data->ClearRects();
        MyRefresh();
        GetParent()->Refresh();
    }
}
//------------------------------------------------------------------------------
void ControlDialog::OnColorChoice(wxCommandEvent& event)
{
    m_Data->SetBackgroundColor(event.GetInt());
    GetParent()->Refresh();
}
//------------------------------------------------------------------------------
void ControlDialog::OnPeriodSpin(wxCommandEvent& event)
{
    m_Data->SetPeriod(m_PeriodSpinCtrl->GetValue());
}
//------------------------------------------------------------------------------
