///File : MainFrame.cpp
//------------------------------------------------------------------------------
/*
    This file is part of LCDnurse.

    LCDnurse is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LCDnurse is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LCDnurse.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "MainFrame.hpp"
//------------------------------------------------------------------------------
BEGIN_EVENT_TABLE(MainFrame, wxFrame)
    EVT_CLOSE(MainFrame::OnFrameClose)
END_EVENT_TABLE()

//------------------------------------------------------------------------------
void MainFrame::OnFrameClose(wxCloseEvent& event)
{
    event.Veto();
    if(m_Data.IsFileChanged())
    {
        switch(wxMessageBox(_("Do you want to save the LCDnurse configuration ?"), _("Quit"), wxYES_NO | wxCANCEL | wxYES_DEFAULT | wxICON_QUESTION, this))
        {
            case wxYES:
                if(!m_Data.SaveCfg())
                {
                    wxMessageBox(_("Can't save config file !"), _("Save"), wxOK | wxICON_EXCLAMATION, this);
                    event.Veto();
                }
                else
                {
                    Destroy();
                }
                break;
            case wxNO:
                Destroy();
                break;
            case wxCANCEL:
                event.Veto();
                break;
        }
    }
    else
    {
        Destroy();
    }
}
//------------------------------------------------------------------------------
MainFrame::MainFrame(const wxString& title, const wxPoint& pos, const wxSize& size, long style) : wxFrame(NULL, -1, title, pos, size, style)
{
    // Data
    m_Data.LoadCfg();

    // Presentation général
    wxString ImgFileName;
    #if defined(__WXMSW__)
        SetIcon(wxIcon(_T("monicone")));
    #elif defined(__UNIX__)
        ImgFileName = findFile(_T("data/lcdnurse-icon.png"));
        if(wxFileExists(ImgFileName))
        {
            SetIcon(wxIcon(ImgFileName, wxBITMAP_TYPE_PNG));
        }
    #endif //#ifdef WIN32
    SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE));

    // Content
	wxBoxSizer* MainSizer = new wxBoxSizer( wxVERTICAL );

    m_MainPanel = new MainPanel(this, wxID_ANY, &m_Data);

    MainSizer->Add(m_MainPanel, 1, wxEXPAND, 0);

	SetSizer( MainSizer );
}
//------------------------------------------------------------------------------
